
#include "mainframe.h"
#include <gtkmm/stock.h>
#include <iostream>

MAINFRAME::MAINFRAME()
:  Game()
{
  set_title("4 Gewinnt");
  set_border_width(12);
  set_default_size(400, 400);
  add(m_Box); // put a MenuBar at the top of the box and other stuff below it.

  //Create actions for menus and toolbars:
  m_refActionGroup = Gtk::ActionGroup::create();

  //File|New sub menu:
  m_refActionGroup->add(Gtk::Action::create("FileMenu", "File"));

    //Sub-menu.
  m_refActionGroup->add(Gtk::Action::create("FileNewGame",
              Gtk::Stock::NEW, "_New Game", "Create a new game"),
          sigc::mem_fun(*this, &MAINFRAME::menu_new_game));


  m_refActionGroup->add(Gtk::Action::create("Options", Gtk::Stock::EDIT,"Options","Game Options"));
  m_refActionGroup->add(Gtk::Action::create("PVPC",
              Gtk::Stock::EXECUTE, "PVPC", "Player Vs PC"),
          bind(sigc::mem_fun(*this, &MAINFRAME::options),-1));
  m_refActionGroup->add(Gtk::Action::create("PCVP",
              Gtk::Stock::EXECUTE, "PCVP", "PC Vs Player"),
          bind(sigc::mem_fun(*this, &MAINFRAME::options),1));
  m_refActionGroup->add(Gtk::Action::create("PVP",
              Gtk::Stock::EXECUTE, "PVP", "Player Vs Player"),
          bind(sigc::mem_fun(*this, &MAINFRAME::options),0));

  m_refActionGroup->add(Gtk::Action::create("FileQuit", Gtk::Stock::QUIT),
          sigc::mem_fun(*this, &MAINFRAME::menu_quit));


  //Debug|New sub menu:
  m_refActionGroup->add(Gtk::Action::create("Debug", "Debug"));
  //Sub Menu:
  m_refActionGroup->add(Gtk::Action::create("KIZug",
              Gtk::Stock::EXECUTE, "KIZug", "Debug KIs Zug"),
          sigc::mem_fun(*this, &MAINFRAME::debug));



  m_refUIManager = Gtk::UIManager::create();
  m_refUIManager->insert_action_group(m_refActionGroup);

  add_accel_group(m_refUIManager->get_accel_group());

  //Layout the actions in a menubar and toolbar:
  Glib::ustring ui_info =
        "<ui>"
        "  <menubar name='MenuBar'>"
        "    <menu action='FileMenu'>"
        "      <menuitem action='FileNewGame'/>"
        "      <menu action='Options'>"
        "        <menuitem action='PVPC'/>"
        "        <menuitem action='PCVP'/>"
        "        <menuitem action='PVP'/>"
        "      </menu>"
        "      <menuitem action='FileQuit'/>"
        "    </menu>"
        "    <menu action='Debug'>"
        "      <menuitem action='KIZug'/>"
        "    </menu>"
        "  </menubar>"
        "</ui>";

  try
  {
    m_refUIManager->add_ui_from_string(ui_info);
  }
  catch(const Glib::Error& ex)
  {
    std::cerr << "building menus failed: " <<  ex.what();
  }

  //Get the menubar and toolbar widgets, and add them to a container widget:
  Gtk::Widget* pMenubar = m_refUIManager->get_widget("/MenuBar");
  if(pMenubar)
    m_Box.pack_start(*pMenubar, Gtk::PACK_SHRINK);


//Spielfeld hinzufgen
m_Box.pack_start(Game, Gtk::PACK_EXPAND_WIDGET);

  show_all_children();

}

MAINFRAME::~MAINFRAME()
{
    Game.save_verlauf();
}

void MAINFRAME::menu_quit()
{
  hide(); //Closes the main window to stop the Gtk::Main::run().
}

void MAINFRAME::menu_new_game()
{
    Game.save_verlauf();
    Game.New();
}

void MAINFRAME::options(int pc)
{
Game.save_verlauf();
Game.Spielmodus(pc);
Game.New();
}

void MAINFRAME::debug()
{
    Game.debug_pc_zug();
}
